#
# spec file for package python
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Define just "test" as a package in _multibuild file to distinguish test
# instructions here
%if "" == ""
%define _test 0
%define name_ext %nil
%else
%define _test 1
%define name_ext -test
%endif

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         short_name openqa_review
%define         binaries openqa-review openqa-review-daily-email openqa-review-sles-ha tumblesle-release openqa-review-functional_autoyast_concise
%define         oldpython python
Name:           python-%{short_name}%{?name_ext}
Version:        1.10.0
Release:        lp150.2.1
Summary:        A review helper script for openQA
License:        MIT
Group:          Development/Languages/Python
Source:         https://github.com/okurz/%{short_name}/archive/%{version}.tar.gz#/python-%{short_name}-%{version}.tar.gz
Url:            https://github.com/okurz/%{short_name}
BuildRequires:  python-rpm-macros
%if 0%{?_test}
BuildRequires:  %{oldpython}-%{short_name}
%else
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
# workaround because of python-configparser not providing the '__init__.py'
# file within site-packages/backports
%if "%{python_flavor}" == "python2"
Requires:       python-backports.ssl_match_hostname
Requires:       python-configparser
%endif
Requires:       python-PyYAML
Requires:       python-beautifulsoup4
Requires:       python-certifi
Requires:       python-future
Requires:       python-humanfriendly
Requires:       python-pika
Requires:       python-requests
Requires:       python-setuptools
Requires:       python-sortedcontainers
Requires(post): update-alternatives
Requires(preun): update-alternatives
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%ifpython2
Obsoletes:      %{oldpython}-%{short_name} < %{version}
%endif

%python_subpackages

%description
A review helper script for openQA. For more details look into the README file.

%prep
%if 0%{?_test}
# workaround to prevent post/install failing assuming this file for whatever
# reason
touch %{_sourcedir}/%{short_name}
%else
%setup -q -n %{short_name}-%{version}
# delete shebang of files not in executable path
find %{short_name}/ -name '*.py' -print0 | xargs -0 sed -i '1s/#!.*$//'
%endif

%build
%if 0%{?_test}
openqa-review --help
tumblesle-release --help
%else
%python_build
%endif

%install
%if 0%{?_test}
# disable debug packages in package test to prevent error about missing files
%define debug_package %{nil}
%else
%python_install
rm %{buildroot}/%{python_sitelib}/version.*

for i in %{binaries}; do
    %python_clone -a %{buildroot}%{_bindir}/$i
done
%fdupes %{buildroot}%{_prefix}

%post
%{python_install_alternative %{binaries}}

%preun
%python_uninstall_alternative openqa-review

%files %{python_files}
%defattr(-,root,root,-)
%license LICENSE
%doc README.md
%{python_sitelib}
%python_alternative %{_bindir}/openqa-review
%python_alternative %{_bindir}/openqa-review-sles-ha
%python_alternative %{_bindir}/openqa-review-daily-email
%python_alternative %{_bindir}/openqa-review-functional_autoyast_concise
%python_alternative %{_bindir}/tumblesle-release

%endif

%changelog
* Wed May  2 2018 tchvatal@suse.com
- Move install call on proper location
* Fri Feb  9 2018 okurz@suse.com
- Update to version 1.10.0:
  * Add helper script for SLE15 functional+autoyast concise report
  * Reference new review wrapper script in setup.py
* Thu Feb  8 2018 okurz@suse.com
- Adapt license file location according to new suggestion around %%license
* Wed Feb  7 2018 okurz@suse.com
- Update to version 1.9.0:
  * openqa-review-daily-email: Fix passing of additional options with whitespace
  * Add two options to further abbreviate condensed reports
  * Include difference in numbers on verbosity level above 3
  * Correct optional code for updating reference reports
  * Encode severity together with priority for ticket references
  * Mark closed tickets as red
  * setup.py: Fix flake8 reported style issues with explicit except
  * setup.py: Catch errors as reported on no version.py from OBS build
  * setup.py: python2 backward cruft/craft
* Fri Jan 19 2018 okurz@suse.com
- Update to version 1.8.3:
  * Add 'bgo' bugref
  * Handle unknown bugtrackers gracefully
* Wed Dec 20 2017 okurz@suse.com
- Update to version 1.8.2:
  * browser: Status code is not always available on error
  * setup.py: Correct name of tests_require
  * Project is no production stable
  * Only require separate configparser for python2
  * Fix require of configparser for python3
* Sun Dec 17 2017 okurz@suse.com
- Provide singlespec file with update-alternatives including self-test
  * Better multibuild-evaluation with valid syntax allowing local use of
    '-M test'
  * Complete runtime requirements including "python-setuptools"
  * Complete set of scripts for both python2 and python3
  * Package self-test for all repositories and python2/python3
* Sat Dec 16 2017 okurz@suse.com
- Update to version 1.8.0:
  * Provide job references in failed soft-fail parsing
  * Add review wrapper script for 'functional' group on openqa.suse.de
  * Handle disconnects by remote end on API get gracefully
* Thu Sep 21 2017 okurz@suse.com
- Update version to support more recent openQA web structure (boo#1059661)
* Wed Sep 20 2017 okurz@suse.com
- Update to version 1.7.5:
  * Add preliminary tumblesle release script for SLE 15
  * Support multi-distri job groups with openQA#037ffd33
* Sat Aug 26 2017 okurz@suse.com
- Update to version 1.7.4:
  * Fix error 401 on redmine after server side ngingx update
  * Ignore cscope.out
  * Fix whitespace as reported by flake8
  * Fix handling of dotted build numbers parsing from comments
* Mon Jul 24 2017 okurz@suse.com
- Update to version 1.7.2:
  * Extend soft-fail issue tracker support
* Sun Jul 23 2017 okurz@suse.com
- Update to version 1.7.1:
  * Also parse soft-fail needles
* Fri Jul 21 2017 okurz@suse.com
- Update to version 1.7.0:
  * Skip error on writing reminder comments gracefully
  * Get bugref details for softfails as well
  * Split big 'bugrefs' test into more subtests
  * Remove not used variables (#70)
* Sun Jul 16 2017 okurz@suse.com
- Update to version 1.6.8:
  * .gitignore: Also exclude pycharm
  * Extract reading reference report in test for simpler ref report updating
  * Fix 'interesting_states' not really filtering out STABLE results
  * Use lowercase 'todo' dict key for easier distinction from TODO in source code comments
  * Tiny duplication removal in tox.ini
  * Fix potential wrong import of not-backported configparser within py27 tests
  * Delete again configparser2 reference which is another module
  * Simplify handling of results/results_by_bugref dicts
  * Delete obsolete test data entry for soft-failed with failed modules
  * Use newer python3.6 as in openSUSE Tumbleweed for testing
  * Also include 'IMPROVED' in soft fail states
  * Simplify 'soft-fail' calculation within IssueEntry
  * Delete some redundant soft-fails for easier testing
* Wed Jun 14 2017 okurz@suse.com
- Update to version 1.6.6:
  * Add CLOSED to issue states for non-open tickets (#61)
  * Fix broken HTML
  * Fix doc-strings issue D401, not imperative mood
  * Retry download in case of 502
* Wed Mar 15 2017 okurz@suse.com
- Update to version 1.6.4:
  * Remove unused webtests (#58)
  * dashboard: Prevent duplicate reminder comments
  * Extend review-daily-email for use with opensuse.org
  * Install 'openqa-review-daily-email' script
* Wed Mar 15 2017 okurz@suse.com
- Include new binary 'openqa-review-daily-email'
* Wed Mar  8 2017 okurz@suse.com
- Update to version 1.6.2:
  * dashboard: Correct exclude regex syntax after live test
* Wed Mar  8 2017 okurz@suse.com
- Update to version 1.6.1:
  * Add option to exclude job groups by regex
  * Fix flake8 checks in tumblesle_release
  * Ignore obsolete released and development job groups in dashboard report
* Fri Mar  3 2017 opensuse-packaging@opensuse.org
- Update to version 1.5.2:
  * tumblesle_release: Add optional AMQP authentication
  * Add CII badge after review
  * Replace obsolete gitlab with github reference
  * Fix version file parsing when there is no git tag
  * tumblesle-release: Retry on AMQP connection lost
* Fri Mar  3 2017 okurz@suse.com
- Fix import error on backports.configparser by workaround (boo#1025589)
* Tue Feb 14 2017 opensuse-packaging@opensuse.org
- Update to version 1.5.1:
  * Fix openqa_review_osd_daily_email running in dry-run by default
* Mon Feb  6 2017 opensuse-packaging@opensuse.org
- Update to version 1.5.0:
  * Post issue reminder comments from daily review script
  * tumblesle_release: Add AMQP notification support for 'suse_msg'
  * tumblesle_release: Add documentation for AMQP notifications
  * tumblesle_release: Prevent spammy repetition of AMQP notifications
  * Get rid of duplicate update_jekyll
  * More tumblesle notifications
  * Fix tumblesle script not checking for new builds / updated job results
  * Make tumblesle_release notification connection more resilient
  * tumblesle_release: Only store in notify_seen on success
  * Recommend safer installation proposals
  * Ensure valid python certificates with certifi
  * Be more specific about the error when file not found in cache
  * Ensure all data is cached on save in openqa_review_osd_daily_email
* Thu Jan 26 2017 okurz@suse.com
- Correct missing package content for update to 1.4.1
* Fri Jan 20 2017 opensuse-packaging@opensuse.org
- Update to version 1.4.1:
  * Ignore builds which have an actual empty build value
* Fri Jan 20 2017 opensuse-packaging@opensuse.org
- Update to version 1.4.0:
  * Add tumblesle example scripts
  * Use index.json to get job groups (#36)
  * Prepare for wellformed json (#38)
  * Fix #41: Handle broken bugrefs gracefully (#42)
  * Fix for parent groups: Use API to get job_groups (#43)
  * Use JSON version of group_overview (#44)
  * TODO: Add entry about configparser travis error
  * Ensure configparser is available for py2+3
  * Fix py27 errors only observable on travis
  * Handle job groups with builds not having any 'done' jobs at all
  * Try to get distri/version for each build (#47)
  * Ensure proper URL concatenation on py2 for bug details retrieval
  * Show parent group in report (#48)
  * Add tumblesle helper script for 12sp3
  * Add update_jekyll for tumblesle release
  * Use blank build value without version prefix (#51)
  * Comment on old bugs with new failed test url (#50)
  * Fix flake8 reported issues after 48fb659
  * Fix parsing of job groups after openQA#9b50b22
  * Run all envs on travis
  * Add command line option for '--min-days-unchanged' for reminder comments
* Tue Oct 18 2016 opensuse-packaging@opensuse.org
- Update to version 1.3.2:
  * Fix crash on new-style 'empty builds'
* Tue Oct 18 2016 opensuse-packaging@opensuse.org
- Update to version 1.3.1:
  * Debug output for 'not enough builds'
  * Get rid of possibly already covered exception handling
  * bin: Mark script as executable
  * dashboard: Customize html header content, e.g. title
  * tumblesle_release: Regard 'softfailed' in newer versions of openQA as passed
* Thu Oct  6 2016 opensuse-packaging@opensuse.org
- Update to version 1.3.1:
  * tests: Correct test files for 'after_61b4db60'
  * Prevent "no builds" found for weird combination of python packages for some users
* Thu Sep 29 2016 opensuse-packaging@opensuse.org
- Update to version 1.3.0:
  * report_links: Make 'latest' a link in markdown format
  * wip -- add bug report links, also for progress, for later
  * TODO: correct indendation of some entries
  * TODO: Remove implemented bug reporting links
  * browser: Support saving pages with unicode content in python2
  * issue_report_link: Support non-digit builds
  * issue_report_link: Handle non-existing product mapping option gracefully
  * Allow filtering for closed / unassigned bugs
  * TODO: Add some ideas
  * Add dashboard generation script
  * Store dashboard file at common "bin" location
  * Delete unnecessary bootstrap.js and font files
  * Add LICENSE.GPL-2 for files under dashboard_files/
  * dashboard: Use robust 'sh -e' shebang
  * Add bin/openqa_review_osd_daily_email script
  * dashboard: Make all variables options with defaults
  * dashboard: Replace three-step sed replace by proper template replace
  * dashboard: Customize logo with a big 'R' on top for 'review'
  * Merge 'dashboard' and 'openqa_review_osd_daily_email'
  * issue_report_link: Fix unsupported failures without failed modules
  * TODO: Mark 'use test verbosity for existing' as fixed
  * Do not fail when there are no closed/unass bugs (#28)
  * Fix #21: Put hr to own line and use md syntax (#29)
  * Make hr between products on dashboard page thicker (#31)
  * Fix ") in issue subject breaking markdown (#30)
  * Support new-style progress bars of openQA
* Wed Sep 21 2016 opensuse-packaging@opensuse.org
- Update to version 1.2.0:
  * Display ticket priority (#25)
  * Show __doc__ as port of help
  * Add links to verbose reports to directly report bugs
  * Use host specific issue tracker product mapping
  * Ensure multiple missing archs are sorted
  * Add more information to bug report links
* Tue Sep 20 2016 opensuse-packaging@opensuse.org
- Update to version 1.1.0:
  * Get objects up into the main function (#22)
  * Fix arch matching (#23)
  * Treat incomplete->failed as new failures
* Mon Sep 19 2016 opensuse-packaging@opensuse.org
- Update to version 1.0.0:
  * Simplify script usage (#13)
  * Add Browser cache (#15)
  * Be more strict about bugrefs read on openQA webpages
  * Use Objects to handle Issues and ArchReport
  * Add .swp files to .gitignore
  * Fix soft failed: Use new 'result_softfailed' str
  * TODO: Add idea about bug reporting links
  * Add ArchReports and IssueEntry obj (#19)
  * '-r' and '-T' are not mutually exclusive anymore
  * Get objects up into the main function (#22)
* Tue Sep 13 2016 opensuse-packaging@opensuse.org
- Update to version 0.8.1:
  * Fix 'missing architectures' entry not yielding proper table row
  * Fix D403 style issues
  * Prevent flake8 check running on existing .tox dir
  * Ensure proper python2+3 testing on different distributions
  * TODO: DONE "Using labels …" with commit fd1b373
  * TODO: DONE "package for openSUSE"
* Mon Sep 12 2016 opensuse-packaging@opensuse.org
- Update to version 0.8.0:
  * Read Bugzilla issue status & subject (#8)
  * Fix config parsing for python2 (#9)
  * Fix insecure ssl warning (#10)
  * TODO: Add reference to mass bug filing tool
  * Let --query-issue-status" arg implie --bugrefs (#11)
  * Extract Browser into module
  * Extract report generator object for 'new issue'
  * Use absolute imports for python2
* Thu Aug 25 2016 opensuse-packaging@opensuse.org
- Update to version 0.7.1:
  * .travis.yml: Add pypi deploy commands
  * Correct name in setup.py to 'openqa_review'
  * Add reference for pypi deploy to .travis.yml
  * Accept 'not enough finished builds' as expected behaviour
  * Prevent inactive job groups showing up in openQA >= 4.4
  * Add wrapper script for SLES/HA review
  * Correct markdown syntax of code segments
  * Handle download errors graciously
  * Correct log message for saving files in Browser
  * Fix 'KeyError TODO' with builds having only bugref'd jobs
* Sun Jan 24 2016 okurz@suse.de
- initial package
